#[non_exhaustive]pub enum Direction {
Unspecified,
Ascending,
Descending,
UnknownValue(UnknownValue),
}Expand description
The direction determines how a property is indexed.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The direction is unspecified.
Ascending
The property’s values are indexed so as to support sequencing in ascending order and also query by <, >, <=, >=, and =.
Descending
The property’s values are indexed so as to support sequencing in descending order and also query by <, >, <=, >=, and =.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Direction::value or Direction::name.
Implementations