#[non_exhaustive]pub struct ExportEntitiesRequest {
pub project_id: String,
pub labels: HashMap<String, String>,
pub entity_filter: Option<EntityFilter>,
pub output_url_prefix: String,
/* private fields */
}Expand description
The request for google.datastore.admin.v1.DatastoreAdmin.ExportEntities.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID against which to make the request.
labels: HashMap<String, String>Client-assigned labels.
entity_filter: Option<EntityFilter>Description of what data from the project is included in the export.
output_url_prefix: StringRequired. Location for the export metadata and data files.
The full resource URL of the external storage location. Currently, only
Google Cloud Storage is supported. So output_url_prefix should be of the
form: gs://BUCKET_NAME[/NAMESPACE_PATH], where BUCKET_NAME is the
name of the Cloud Storage bucket and NAMESPACE_PATH is an optional Cloud
Storage namespace path (this is not a Cloud Datastore namespace). For more
information about Cloud Storage namespace paths, see
Object name
considerations.
The resulting files will be nested deeper than the specified URL prefix. The final output URL will be provided in the google.datastore.admin.v1.ExportEntitiesResponse.output_url field. That value should be used for subsequent ImportEntities operations.
By nesting the data files deeper, the same Cloud Storage bucket can be used in multiple ExportEntities operations without conflict.
Implementations
Sourceimpl ExportEntitiesRequest
impl ExportEntitiesRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = ExportEntitiesRequest::new().set_project_id("example");Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_entity_filter<T>(self, v: T) -> Selfwhere
T: Into<EntityFilter>,
pub fn set_entity_filter<T>(self, v: T) -> Selfwhere
T: Into<EntityFilter>,
Sets the value of entity_filter.
Example
use google_cloud_datastore_admin_v1::model::EntityFilter;
let x = ExportEntitiesRequest::new().set_entity_filter(EntityFilter::default()/* use setters */);Sourcepub fn set_or_clear_entity_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<EntityFilter>,
pub fn set_or_clear_entity_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<EntityFilter>,
Sets or clears the value of entity_filter.
Example
use google_cloud_datastore_admin_v1::model::EntityFilter;
let x = ExportEntitiesRequest::new().set_or_clear_entity_filter(Some(EntityFilter::default()/* use setters */));
let x = ExportEntitiesRequest::new().set_or_clear_entity_filter(None::<EntityFilter>);Sourcepub fn set_output_url_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_output_url_prefix<T: Into<String>>(self, v: T) -> Self
Sets the value of output_url_prefix.
Example
let x = ExportEntitiesRequest::new().set_output_url_prefix("example");Trait Implementations
Sourceimpl Clone for ExportEntitiesRequest
impl Clone for ExportEntitiesRequest
Sourcefn clone(&self) -> ExportEntitiesRequest
fn clone(&self) -> ExportEntitiesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExportEntitiesRequest
impl Debug for ExportEntitiesRequest
Sourceimpl Default for ExportEntitiesRequest
impl Default for ExportEntitiesRequest
Sourcefn default() -> ExportEntitiesRequest
fn default() -> ExportEntitiesRequest
Sourceimpl Message for ExportEntitiesRequest
impl Message for ExportEntitiesRequest
Sourceimpl PartialEq for ExportEntitiesRequest
impl PartialEq for ExportEntitiesRequest
impl StructuralPartialEq for ExportEntitiesRequest