#[non_exhaustive]pub struct ImportEntitiesRequest {
pub project_id: String,
pub labels: HashMap<String, String>,
pub input_url: String,
pub entity_filter: Option<EntityFilter>,
/* private fields */
}Expand description
The request for google.datastore.admin.v1.DatastoreAdmin.ImportEntities.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. Project ID against which to make the request.
labels: HashMap<String, String>Client-assigned labels.
input_url: StringRequired. The full resource URL of the external storage location.
Currently, only Google Cloud Storage is supported. So input_url should be
of the form:
gs://BUCKET_NAME[/NAMESPACE_PATH]/OVERALL_EXPORT_METADATA_FILE, where
BUCKET_NAME is the name of the Cloud Storage bucket, NAMESPACE_PATH is
an optional Cloud Storage namespace path (this is not a Cloud Datastore
namespace), and OVERALL_EXPORT_METADATA_FILE is the metadata file written
by the ExportEntities operation. For more information about Cloud Storage
namespace paths, see
Object name
considerations.
For more information, see google.datastore.admin.v1.ExportEntitiesResponse.output_url.
entity_filter: Option<EntityFilter>Optionally specify which kinds/namespaces are to be imported. If provided, the list must be a subset of the EntityFilter used in creating the export, otherwise a FAILED_PRECONDITION error will be returned. If no filter is specified then all entities from the export are imported.
Implementations
Sourceimpl ImportEntitiesRequest
impl ImportEntitiesRequest
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = ImportEntitiesRequest::new().set_project_id("example");Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_input_url<T: Into<String>>(self, v: T) -> Self
pub fn set_input_url<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_entity_filter<T>(self, v: T) -> Selfwhere
T: Into<EntityFilter>,
pub fn set_entity_filter<T>(self, v: T) -> Selfwhere
T: Into<EntityFilter>,
Sets the value of entity_filter.
Example
use google_cloud_datastore_admin_v1::model::EntityFilter;
let x = ImportEntitiesRequest::new().set_entity_filter(EntityFilter::default()/* use setters */);Sourcepub fn set_or_clear_entity_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<EntityFilter>,
pub fn set_or_clear_entity_filter<T>(self, v: Option<T>) -> Selfwhere
T: Into<EntityFilter>,
Sets or clears the value of entity_filter.
Example
use google_cloud_datastore_admin_v1::model::EntityFilter;
let x = ImportEntitiesRequest::new().set_or_clear_entity_filter(Some(EntityFilter::default()/* use setters */));
let x = ImportEntitiesRequest::new().set_or_clear_entity_filter(None::<EntityFilter>);Trait Implementations
Sourceimpl Clone for ImportEntitiesRequest
impl Clone for ImportEntitiesRequest
Sourcefn clone(&self) -> ImportEntitiesRequest
fn clone(&self) -> ImportEntitiesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ImportEntitiesRequest
impl Debug for ImportEntitiesRequest
Sourceimpl Default for ImportEntitiesRequest
impl Default for ImportEntitiesRequest
Sourcefn default() -> ImportEntitiesRequest
fn default() -> ImportEntitiesRequest
Sourceimpl Message for ImportEntitiesRequest
impl Message for ImportEntitiesRequest
Sourceimpl PartialEq for ImportEntitiesRequest
impl PartialEq for ImportEntitiesRequest
impl StructuralPartialEq for ImportEntitiesRequest